@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::PluginBundle::Author::GETTY::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $Dist::Zilla::PluginBundle::Author::GETTY::VERSION = '0.011';
+  $Dist::Zilla::PluginBundle::Author::GETTY::VERSION = '0.012';
 }
 # ABSTRACT: BeLike::GETTY when you build your dists
 
@@ -72,6 +72,13 @@ has no_cpan => (
   default => sub { $_[0]->payload->{no_cpan} },
 );
 
+has no_travis => (
+  is      => 'ro',
+  isa     => 'Bool',
+  lazy    => 1,
+  default => sub { $_[0]->payload->{no_travis} },
+);
+
 has no_install => (
   is      => 'ro',
   isa     => 'Bool',
@@ -203,6 +210,12 @@ sub configure {
 		GithubMeta
 	));
 
+  unless ($self->no_travis) {
+    $self->add_plugins(qw(
+      TravisYML
+    ));
+  }
+
   if ($self->is_alien) {
     my %alien_values;
     for (@alien_options) {
@@ -291,11 +304,11 @@ Dist::Zilla::PluginBundle::Author::GETTY - BeLike::GETTY when you build your dis
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
-  name    = Alien-ffmpeg
+  name    = Your-App
   author  = You User <you@universe.org>
   license = Perl_5
   copyright_holder = You User
@@ -314,6 +327,7 @@ are default):
   release_branch = master
   weaver_config = @Author::GETTY
   no_cpan = 0
+  no_travis = 0
   duckpan = 0
   no_install = 0
   no_makemaker = 0
@@ -331,6 +345,8 @@ In default configuration it is equivalent to:
   [NextRelease]
   [PodSyntaxTests]
   [GithubMeta]
+  [TravisYML]
+
   [InstallRelease]
   install_command = cpanm .
 
@@ -417,6 +433,11 @@ L<Dist::Zilla::Plugin::PodWeaver>.
 If set to 1, this attribute will disable L<Dist::Zilla::Plugin::UploadToCPAN>.
 By default a dzil release would release to L<CPAN|http://www.cpan.org/>.
 
+=head2 no_travis
+
+If set to 1, this attribute will disable L<Dist::Zilla::TravisCI>. By default a
+dzil build or release would also generate a B<.travis.yml>.
+
 =head2 duckpan
 
 If set to 1, this attribute will activate L<Dist::Zilla::Plugin::UploadToDuckPAN>.
@@ -432,6 +453,10 @@ If set to 1, the resulting distribution can't be installed.
 
 =head2 no_makemaker
 
+If set to 1, the resulting distribution will not use L<Dist::Zilla::Plugin::MakeMaker>.
+This is an internal function, and you should know what you do, if you activate
+this flag.
+
 =head2 no_installrelease
 
 By default, this bundle will install your distribution after the release. If
@@ -478,6 +503,8 @@ L<Dist::Zilla::Plugin::TaskWeaver>
 
 L<Dist::Zilla::Plugin::UploadToDuckPAN>
 
+L<Dist::Zilla::TravisCI>
+
 =head1 AUTHOR
 
 Torsten Raudssus <torsten@raudss.us> L<http://www.raudss.us/>
